@@ -75,12 +75,15 @@ class Renderer(collection.Renderer):
             title = ''
         if field is not None:
             if field.get_size(context) != 0:
-                portal = getUtility(IPloneSiteRoot)
-                prefs =  ILeadImagePrefsForm(portal)
-                scale = prefs.desc_scale_name
+                scale = self.scale()
                 return field.tag(context, scale=scale, css_class=css_class, title=title)
         return ''
 
+    def scale(self):
+        portal = getUtility(IPloneSiteRoot)
+        prefs =  ILeadImagePrefsForm(portal)
+        return prefs.desc_scale_name
+
     def object_date(self, brain):
         """ Return the appropiate date to show """
 
@@ -92,7 +95,6 @@ class Renderer(collection.Renderer):
         return date
 
 
-
 class AddForm(base.AddForm):
     """Portlet add form.
 
