@@ -1,4 +1,4 @@
-from Products.Five import zcml
+from Zope2.App import zcml
 from Products.Five import fiveconfigure
 
 from Testing import ZopeTestCase as ztc
